"use strict";
/**
 * Http Status Codes
 *
 * HTTP response status codes indicate whether a specific HTTP request has been successfully completed.
 * Responses are grouped in five classes:
 *
 * Informational responses [100–199]
 * Successful responses [200–299]
 * Redirection messages [300–399]
 * Client error responses [400–499]
 * Server error responses [500–599]
 *
 * Source {@link https://developer.mozilla.org/en-US/docs/Web/HTTP/Status}
 *
 * @export
 * @enum {number}
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusCode = void 0;
var StatusCode;
(function (StatusCode) {
    /**
     * @description This interim response indicates that the client should continue the request or ignore the response if the request is already finished.
     */
    StatusCode[StatusCode["CONTINUE"] = 100] = "CONTINUE";
    /**
     * @description This code is sent in response to an Upgrade request header from the client and indicates the protocol the server is switching to.
     */
    StatusCode[StatusCode["SWITCHING_PROTOCOLS"] = 101] = "SWITCHING_PROTOCOLS";
    /**
     * @description This code indicates that the server has received and is processing the request, but no response is available yet.
     */
    StatusCode[StatusCode["PROCESSING"] = 102] = "PROCESSING";
    /**
     * @description This status code is primarily intended to be used with the Link header, letting the user agent start preloading resources while the server prepares a response.
     */
    StatusCode[StatusCode["EARLY_HINTS"] = 103] = "EARLY_HINTS";
    /**
     * @description -
     */
    StatusCode[StatusCode["OK"] = 200] = "OK";
    /**
     * @description - @
     */
    StatusCode[StatusCode["CREATED"] = 201] = "CREATED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["ACCEPTED"] = 202] = "ACCEPTED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NON_AUTHORITATIVE_INFORMATION"] = 203] = "NON_AUTHORITATIVE_INFORMATION";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NO_CONTENT"] = 204] = "NO_CONTENT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["RESET_CONTENT"] = 205] = "RESET_CONTENT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PARTIAL_CONTENT"] = 206] = "PARTIAL_CONTENT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["MULTIPLE_CHOICES"] = 300] = "MULTIPLE_CHOICES";
    /**
     * @description - @
     */
    StatusCode[StatusCode["MOVED_PERMANENTLY"] = 301] = "MOVED_PERMANENTLY";
    /**
     * @description - @
     */
    StatusCode[StatusCode["FOUND"] = 302] = "FOUND";
    /**
     * @description - @
     */
    StatusCode[StatusCode["SEE_OTHER"] = 303] = "SEE_OTHER";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NOT_MODIFIED"] = 304] = "NOT_MODIFIED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["TEMPORARY_REDIRECT"] = 307] = "TEMPORARY_REDIRECT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PERMANENT_REDIRECT"] = 308] = "PERMANENT_REDIRECT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["BAD_REQUEST"] = 400] = "BAD_REQUEST";
    /**
     * @description - @
     */
    StatusCode[StatusCode["UNAUTHORIZED"] = 401] = "UNAUTHORIZED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PAYMENT_REQUIRED"] = 402] = "PAYMENT_REQUIRED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["FORBIDDEN"] = 403] = "FORBIDDEN";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NOT_FOUND"] = 404] = "NOT_FOUND";
    /**
     * @description - @
     */
    StatusCode[StatusCode["METHOD_NOT_ALLOWED"] = 405] = "METHOD_NOT_ALLOWED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NOT_ACCEPTABLE"] = 406] = "NOT_ACCEPTABLE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PROXY_AUTHENTICATION_REQUIRED"] = 407] = "PROXY_AUTHENTICATION_REQUIRED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["REQUEST_TIMEOUT"] = 408] = "REQUEST_TIMEOUT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["CONFLICT"] = 409] = "CONFLICT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["GONE"] = 410] = "GONE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["LENGTH_REQUIRED"] = 411] = "LENGTH_REQUIRED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PRECONDITION_FAILED"] = 412] = "PRECONDITION_FAILED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PAYLOAD_TOO_LARGE"] = 413] = "PAYLOAD_TOO_LARGE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["URI_TOO_LONG"] = 414] = "URI_TOO_LONG";
    /**
     * @description - @
     */
    StatusCode[StatusCode["UNSUPPORTED_MEDIA_TYPE"] = 415] = "UNSUPPORTED_MEDIA_TYPE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["RANGE_NOT_SATISFIABLE"] = 416] = "RANGE_NOT_SATISFIABLE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["EXPECTATION_FAILED"] = 417] = "EXPECTATION_FAILED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["IM_A_TEAPOT"] = 418] = "IM_A_TEAPOT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["UNPROCESSABLE_ENTITY"] = 422] = "UNPROCESSABLE_ENTITY";
    /**
     * @description - @
     */
    StatusCode[StatusCode["TOO_EARLY"] = 425] = "TOO_EARLY";
    /**
     * @description - @
     */
    StatusCode[StatusCode["UPGRADE_REQUIRED"] = 426] = "UPGRADE_REQUIRED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["PRECONDITION_REQUIRED"] = 428] = "PRECONDITION_REQUIRED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["TOO_MANY_REQUESTS"] = 429] = "TOO_MANY_REQUESTS";
    /**
     * @description - @
     */
    StatusCode[StatusCode["REQUEST_HEADER_FIELDS_TOO_LARGE"] = 431] = "REQUEST_HEADER_FIELDS_TOO_LARGE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["UNAVAILABLE_FOR_LEGAL_REASONS"] = 451] = "UNAVAILABLE_FOR_LEGAL_REASONS";
    /**
     * @description - @
     */
    StatusCode[StatusCode["INTERNAL_SERVER_ERROR"] = 500] = "INTERNAL_SERVER_ERROR";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NOT_IMPLEMENTED"] = 501] = "NOT_IMPLEMENTED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["BAD_GATEWAY"] = 502] = "BAD_GATEWAY";
    /**
     * @description - @
     */
    StatusCode[StatusCode["SERVICE_UNAVAILABLE"] = 503] = "SERVICE_UNAVAILABLE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["GATEWAY_TIMEOUT"] = 504] = "GATEWAY_TIMEOUT";
    /**
     * @description - @
     */
    StatusCode[StatusCode["HTTP_VERSION_NOT_SUPPORTED"] = 505] = "HTTP_VERSION_NOT_SUPPORTED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["VARIANT_ALSO_NEGOTIATES"] = 506] = "VARIANT_ALSO_NEGOTIATES";
    /**
     * @description - @
     */
    StatusCode[StatusCode["INSUFFICIENT_STORAGE"] = 507] = "INSUFFICIENT_STORAGE";
    /**
     * @description - @
     */
    StatusCode[StatusCode["LOOP_DETECTED"] = 508] = "LOOP_DETECTED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NOT_EXTENDED"] = 510] = "NOT_EXTENDED";
    /**
     * @description - @
     */
    StatusCode[StatusCode["NETWORK_AUTHENTICATION_REQUIRED"] = 511] = "NETWORK_AUTHENTICATION_REQUIRED";
})(StatusCode = exports.StatusCode || (exports.StatusCode = {}));
